'''OpenGL extension EXT.texture3D

This module customises the behaviour of the 
OpenGL.raw.GL.EXT.texture3D to provide a more 
Python-friendly API

Overview (from the spec)
	
	This extension defines 3-dimensional texture mapping.  In order to
	define a 3D texture image conveniently, this extension also defines the
	in-memory formats for 3D images, and adds pixel storage modes to support
	them.
	
	One important application of 3D textures is rendering volumes of image
	data.

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/EXT/texture3D.txt
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions, wrapper
from OpenGL.GL import glget
import ctypes
from OpenGL.raw.GL.EXT.texture3D import *
### END AUTOGENERATED SECTION


#! /usr/bin/env python
"""Simple setup script that installs Tcl/Tk Togl widget into PyOpenGL"""
import OpenGL,sys, os, shutil, logging, urllib, tarfile, zipfile, fnmatch
import optparse
log = logging.getLogger( 'togl-setup' )

if sys.maxint > 2L**32:
    suffix = '-64'
else:
    suffix = ''
# These three define what software we're going to install...
TOGL_VERSION = '2.0'
COMPILED_TK_VERSION = '8.4'
BASE_URL = 'http://downloads.sourceforge.net/project/togl/Togl'

DOWNLOAD_TEMPLATE = '%(BASE_URL)s/%(TOGL_VERSION)s/Togl%(TOGL_VERSION)s-%(COMPILED_TK_VERSION)s-%%s?use_mirror=iweb'%globals()

urls = {
    'win32': DOWNLOAD_TEMPLATE%('Windows.zip',),
    'linux2': DOWNLOAD_TEMPLATE%('Linux.tar.gz',),
    'linux2-64': DOWNLOAD_TEMPLATE%('Linux64.tar.gz',),
    'darwin': DOWNLOAD_TEMPLATE%('MacOSX.tar.gz',),
}
#urls['linux2-64'] = 'Togl2.0-8.4-Linux64.tar.gz'

WANTED_FILES = 'Togl%(TOGL_VERSION)s-%(COMPILED_TK_VERSION)s-*/lib/Togl%(TOGL_VERSION)s/*'%globals()

def setup( key=None, force=False ):
    """Do setup by creating and populating the directories
    
    This incredibly dumb script is intended to let you unpack 
    the Tcl/Tk library Togl from SourceForce into your 
    PyOpenGL 3.0.1 (or above) distribution.
    
    Note: will not work with win64, both because there is no 
        win64 package and because we don't have a url defined 
        for it.
    """
    if key is None:
        key = '%s%s'%( sys.platform,suffix )
    log.info( 'Doing setup for platform key: %s', key )
    target_directory = os.path.join( 
        os.path.dirname( OpenGL.__file__ ),
        'Tk',
        'togl-%s'%( key, ),
    )
    log.info( 'Target directory: %s', target_directory )
    if key not in urls:
        log.error(
            """URL for platform key %s is not present, please update script""",
            key,
        )
        sys.exit( 1 )
    if os.path.exists( target_directory ):
        return False
    
    url = urls[key]
    log.info( 'Downloading: %s', url )
    filename,headers = urllib.urlretrieve( url )
    log.info( 'Downloaded to: %s', filename )
    if not os.path.isdir( target_directory ):
        log.warn( 'Creating directory: %s', target_directory )
        try:
            os.makedirs( target_directory )
        except OSError, err:
            log.error( "Unable to create directory: %s", target_directory )
            sys.exit( 2 )
    if '.tar.gz' in url:
        log.info( 'Opening TarFile' )
        fh = tarfile.open( filename, 'r:gz')
        def getnames():
            return fh.getnames()
        def getfile( name ):
            return fh.extractfile( name )
    elif '.zip' in url:
        log.info( 'Opening ZipFile' )
        fh = zipfile.ZipFile( filename )
        def getnames():
            return fh.namelist()
        def getfile( name ):
            return fh.open( name )
    try:
        for name in getnames():
            log.debug( 'Found file: %s', name )
            if fnmatch.fnmatch( name, WANTED_FILES ):
                if not name.endswith( '/' ):
                    log.info( 'Found wanted file: %s', name )
                    source = getfile( name )
                    try:
                        new = os.path.join(
                            target_directory,
                            os.path.basename( name ),
                        )
                        log.info( 'Writing file: %s', new )
                        open( new,'wb' ).write( source.read() )
                    finally:
                        if hasattr( source, 'close' ):
                            source.close()
    finally:
        fh.close()
        if filename != url:
            os.remove( filename )
    return True 

if __name__ == "__main__":
    logging.basicConfig(level=logging.INFO)
    if sys.argv[1:]:
        if sys.argv[1] == 'all':
            keys = urls.keys()
        else:
            keys = sys.arv[1:]
        for key in keys:
            setup( key )
    else:
        setup()



'''OpenGL extension EXT.framebuffer_sRGB

Automatically generated by the get_gl_extensions script, do not edit!
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions
from OpenGL.GL import glget
import ctypes
EXTENSION_NAME = 'GL_EXT_framebuffer_sRGB'
_DEPRECATED = False
GL_FRAMEBUFFER_SRGB_EXT = constant.Constant( 'GL_FRAMEBUFFER_SRGB_EXT', 0x8DB9 )
GL_FRAMEBUFFER_SRGB_CAPABLE_EXT = constant.Constant( 'GL_FRAMEBUFFER_SRGB_CAPABLE_EXT', 0x8DBA )


def glInitFramebufferSrgbEXT():
    '''Return boolean indicating whether this extension is available'''
    return extensions.hasGLExtension( EXTENSION_NAME )



'''OpenGL extension SUN.vertex

Automatically generated by the get_gl_extensions script, do not edit!
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions
from OpenGL.GL import glget
import ctypes
EXTENSION_NAME = 'GL_SUN_vertex'
_DEPRECATED = False

glColor4ubVertex2fSUN = platform.createExtensionFunction( 
'glColor4ubVertex2fSUN',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLubyte,constants.GLubyte,constants.GLubyte,constants.GLubyte,constants.GLfloat,constants.GLfloat,),
doc='glColor4ubVertex2fSUN(GLubyte(r), GLubyte(g), GLubyte(b), GLubyte(a), GLfloat(x), GLfloat(y)) -> None',
argNames=('r','g','b','a','x','y',),
deprecated=_DEPRECATED,
)

glColor4ubVertex2fvSUN = platform.createExtensionFunction( 
'glColor4ubVertex2fvSUN',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(arrays.GLubyteArray,arrays.GLfloatArray,),
doc='glColor4ubVertex2fvSUN(GLubyteArray(c), GLfloatArray(v)) -> None',
argNames=('c','v',),
deprecated=_DEPRECATED,
)

glColor4ubVertex3fSUN = platform.createExtensionFunction( 
'glColor4ubVertex3fSUN',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLubyte,constants.GLubyte,constants.GLubyte,constants.GLubyte,constants.GLfloat,constants.GLfloat,constants.GLfloat,),
doc='glColor4ubVertex3fSUN(GLubyte(r), GLubyte(g), GLubyte(b), GLubyte(a), GLfloat(x), GLfloat(y), GLfloat(z)) -> None',
argNames=('r','g','b','a','x','y','z',),
deprecated=_DEPRECATED,
)

glColor4ubVertex3fvSUN = platform.createExtensionFunction( 
'glColor4ubVertex3fvSUN',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(arrays.GLubyteArray,arrays.GLfloatArray,),
doc='glColor4ubVertex3fvSUN(GLubyteArray(c), GLfloatArray(v)) -> None',
argNames=('c','v',),
deprecated=_DEPRECATED,
)

glColor3fVertex3fSUN = platform.createExtensionFunction( 
'glColor3fVertex3fSUN',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLfloat,constants.GLfloat,constants.GLfloat,constants.GLfloat,constants.GLfloat,constants.GLfloat,),
doc='glColor3fVertex3fSUN(GLfloat(r), GLfloat(g), GLfloat(b), GLfloat(x), GLfloat(y), GLfloat(z)) -> None',
argNames=('r','g','b','x','y','z',),
deprecated=_DEPRECATED,
)

glColor3fVertex3fvSUN = platform.createExtensionFunction( 
'glColor3fVertex3fvSUN',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(arrays.GLfloatArray,arrays.GLfloatArray,),
doc='glColor3fVertex3fvSUN(GLfloatArray(c), GLfloatArray(v)) -> None',
argNames=('c','v',),
deprecated=_DEPRECATED,
)

glNormal3fVertex3fSUN = platform.createExtensionFunction( 
'glNormal3fVertex3fSUN',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLfloat,constants.GLfloat,constants.GLfloat,constants.GLfloat,constants.GLfloat,constants.GLfloat,),
doc='glNormal3fVertex3fSUN(GLfloat(nx), GLfloat(ny), GLfloat(nz), GLfloat(x), GLfloat(y), GLfloat(z)) -> None',
argNames=('nx','ny','nz','x','y','z',),
deprecated=_DEPRECATED,
)

glNormal3fVertex3fvSUN = platform.createExtensionFunction( 
'glNormal3fVertex3fvSUN',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(arrays.GLfloatArray,arrays.GLfloatArray,),
doc='glNormal3fVertex3fvSUN(GLfloatArray(n), GLfloatArray(v)) -> None',
argNames=('n','v',),
deprecated=_DEPRECATED,
)

glColor4fNormal3fVertex3fSUN = platform.createExtensionFunction( 
'glColor4fNormal3fVertex3fSUN',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLfloat,constants.GLfloat,constants.GLfloat,constants.GLfloat,constants.GLfloat,constants.GLfloat,constants.GLfloat,constants.GLfloat,constants.GLfloat,constants.GLfloat,),
doc='glColor4fNormal3fVertex3fSUN(GLfloat(r), GLfloat(g), GLfloat(b), GLfloat(a), GLfloat(nx), GLfloat(ny), GLfloat(nz), GLfloat(x), GLfloat(y), GLfloat(z)) -> None',
argNames=('r','g','b','a','nx','ny','nz','x','y','z',),
deprecated=_DEPRECATED,
)

glColor4fNormal3fVertex3fvSUN = platform.createExtensionFunction( 
'glColor4fNormal3fVertex3fvSUN',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(arrays.GLfloatArray,arrays.GLfloatArray,arrays.GLfloatArray,),
doc='glColor4fNormal3fVertex3fvSUN(GLfloatArray(c), GLfloatArray(n), GLfloatArray(v)) -> None',
argNames=('c','n','v',),
deprecated=_DEPRECATED,
)

glTexCoord2fVertex3fSUN = platform.createExtensionFunction( 
'glTexCoord2fVertex3fSUN',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLfloat,constants.GLfloat,constants.GLfloat,constants.GLfloat,constants.GLfloat,),
doc='glTexCoord2fVertex3fSUN(GLfloat(s), GLfloat(t), GLfloat(x), GLfloat(y), GLfloat(z)) -> None',
argNames=('s','t','x','y','z',),
deprecated=_DEPRECATED,
)

glTexCoord2fVertex3fvSUN = platform.createExtensionFunction( 
'glTexCoord2fVertex3fvSUN',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(arrays.GLfloatArray,arrays.GLfloatArray,),
doc='glTexCoord2fVertex3fvSUN(GLfloatArray(tc), GLfloatArray(v)) -> None',
argNames=('tc','v',),
deprecated=_DEPRECATED,
)

glTexCoord4fVertex4fSUN = platform.createExtensionFunction( 
'glTexCoord4fVertex4fSUN',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLfloat,constants.GLfloat,constants.GLfloat,constants.GLfloat,constants.GLfloat,constants.GLfloat,constants.GLfloat,constants.GLfloat,),
doc='glTexCoord4fVertex4fSUN(GLfloat(s), GLfloat(t), GLfloat(p), GLfloat(q), GLfloat(x), GLfloat(y), GLfloat(z), GLfloat(w)) -> None',
argNames=('s','t','p','q','x','y','z','w',),
deprecated=_DEPRECATED,
)

glTexCoord4fVertex4fvSUN = platform.createExtensionFunction( 
'glTexCoord4fVertex4fvSUN',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(arrays.GLfloatArray,arrays.GLfloatArray,),
doc='glTexCoord4fVertex4fvSUN(GLfloatArray(tc), GLfloatArray(v)) -> None',
argNames=('tc','v',),
deprecated=_DEPRECATED,
)

glTexCoord2fColor4ubVertex3fSUN = platform.createExtensionFunction( 
'glTexCoord2fColor4ubVertex3fSUN',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLfloat,constants.GLfloat,constants.GLubyte,constants.GLubyte,constants.GLubyte,constants.GLubyte,constants.GLfloat,constants.GLfloat,constants.GLfloat,),
doc='glTexCoord2fColor4ubVertex3fSUN(GLfloat(s), GLfloat(t), GLubyte(r), GLubyte(g), GLubyte(b), GLubyte(a), GLfloat(x), GLfloat(y), GLfloat(z)) -> None',
argNames=('s','t','r','g','b','a','x','y','z',),
deprecated=_DEPRECATED,
)

glTexCoord2fColor4ubVertex3fvSUN = platform.createExtensionFunction( 
'glTexCoord2fColor4ubVertex3fvSUN',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(arrays.GLfloatArray,arrays.GLubyteArray,arrays.GLfloatArray,),
doc='glTexCoord2fColor4ubVertex3fvSUN(GLfloatArray(tc), GLubyteArray(c), GLfloatArray(v)) -> None',
argNames=('tc','c','v',),
deprecated=_DEPRECATED,
)

glTexCoord2fColor3fVertex3fSUN = platform.createExtensionFunction( 
'glTexCoord2fColor3fVertex3fSUN',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLfloat,constants.GLfloat,constants.GLfloat,constants.GLfloat,constants.GLfloat,constants.GLfloat,constants.GLfloat,constants.GLfloat,),
doc='glTexCoord2fColor3fVertex3fSUN(GLfloat(s), GLfloat(t), GLfloat(r), GLfloat(g), GLfloat(b), GLfloat(x), GLfloat(y), GLfloat(z)) -> None',
argNames=('s','t','r','g','b','x','y','z',),
deprecated=_DEPRECATED,
)

glTexCoord2fColor3fVertex3fvSUN = platform.createExtensionFunction( 
'glTexCoord2fColor3fVertex3fvSUN',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(arrays.GLfloatArray,arrays.GLfloatArray,arrays.GLfloatArray,),
doc='glTexCoord2fColor3fVertex3fvSUN(GLfloatArray(tc), GLfloatArray(c), GLfloatArray(v)) -> None',
argNames=('tc','c','v',),
deprecated=_DEPRECATED,
)

glTexCoord2fNormal3fVertex3fSUN = platform.createExtensionFunction( 
'glTexCoord2fNormal3fVertex3fSUN',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLfloat,constants.GLfloat,constants.GLfloat,constants.GLfloat,constants.GLfloat,constants.GLfloat,constants.GLfloat,constants.GLfloat,),
doc='glTexCoord2fNormal3fVertex3fSUN(GLfloat(s), GLfloat(t), GLfloat(nx), GLfloat(ny), GLfloat(nz), GLfloat(x), GLfloat(y), GLfloat(z)) -> None',
argNames=('s','t','nx','ny','nz','x','y','z',),
deprecated=_DEPRECATED,
)

glTexCoord2fNormal3fVertex3fvSUN = platform.createExtensionFunction( 
'glTexCoord2fNormal3fVertex3fvSUN',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(arrays.GLfloatArray,arrays.GLfloatArray,arrays.GLfloatArray,),
doc='glTexCoord2fNormal3fVertex3fvSUN(GLfloatArray(tc), GLfloatArray(n), GLfloatArray(v)) -> None',
argNames=('tc','n','v',),
deprecated=_DEPRECATED,
)

glTexCoord2fColor4fNormal3fVertex3fSUN = platform.createExtensionFunction( 
'glTexCoord2fColor4fNormal3fVertex3fSUN',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLfloat,constants.GLfloat,constants.GLfloat,constants.GLfloat,constants.GLfloat,constants.GLfloat,constants.GLfloat,constants.GLfloat,constants.GLfloat,constants.GLfloat,constants.GLfloat,constants.GLfloat,),
doc='glTexCoord2fColor4fNormal3fVertex3fSUN(GLfloat(s), GLfloat(t), GLfloat(r), GLfloat(g), GLfloat(b), GLfloat(a), GLfloat(nx), GLfloat(ny), GLfloat(nz), GLfloat(x), GLfloat(y), GLfloat(z)) -> None',
argNames=('s','t','r','g','b','a','nx','ny','nz','x','y','z',),
deprecated=_DEPRECATED,
)

glTexCoord2fColor4fNormal3fVertex3fvSUN = platform.createExtensionFunction( 
'glTexCoord2fColor4fNormal3fVertex3fvSUN',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(arrays.GLfloatArray,arrays.GLfloatArray,arrays.GLfloatArray,arrays.GLfloatArray,),
doc='glTexCoord2fColor4fNormal3fVertex3fvSUN(GLfloatArray(tc), GLfloatArray(c), GLfloatArray(n), GLfloatArray(v)) -> None',
argNames=('tc','c','n','v',),
deprecated=_DEPRECATED,
)

glTexCoord4fColor4fNormal3fVertex4fSUN = platform.createExtensionFunction( 
'glTexCoord4fColor4fNormal3fVertex4fSUN',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLfloat,constants.GLfloat,constants.GLfloat,constants.GLfloat,constants.GLfloat,constants.GLfloat,constants.GLfloat,constants.GLfloat,constants.GLfloat,constants.GLfloat,constants.GLfloat,constants.GLfloat,constants.GLfloat,constants.GLfloat,constants.GLfloat,),
doc='glTexCoord4fColor4fNormal3fVertex4fSUN(GLfloat(s), GLfloat(t), GLfloat(p), GLfloat(q), GLfloat(r), GLfloat(g), GLfloat(b), GLfloat(a), GLfloat(nx), GLfloat(ny), GLfloat(nz), GLfloat(x), GLfloat(y), GLfloat(z), GLfloat(w)) -> None',
argNames=('s','t','p','q','r','g','b','a','nx','ny','nz','x','y','z','w',),
deprecated=_DEPRECATED,
)

glTexCoord4fColor4fNormal3fVertex4fvSUN = platform.createExtensionFunction( 
'glTexCoord4fColor4fNormal3fVertex4fvSUN',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(arrays.GLfloatArray,arrays.GLfloatArray,arrays.GLfloatArray,arrays.GLfloatArray,),
doc='glTexCoord4fColor4fNormal3fVertex4fvSUN(GLfloatArray(tc), GLfloatArray(c), GLfloatArray(n), GLfloatArray(v)) -> None',
argNames=('tc','c','n','v',),
deprecated=_DEPRECATED,
)

glReplacementCodeuiVertex3fSUN = platform.createExtensionFunction( 
'glReplacementCodeuiVertex3fSUN',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLfloat,constants.GLfloat,constants.GLfloat,),
doc='glReplacementCodeuiVertex3fSUN(GLuint(rc), GLfloat(x), GLfloat(y), GLfloat(z)) -> None',
argNames=('rc','x','y','z',),
deprecated=_DEPRECATED,
)

glReplacementCodeuiVertex3fvSUN = platform.createExtensionFunction( 
'glReplacementCodeuiVertex3fvSUN',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(arrays.GLuintArray,arrays.GLfloatArray,),
doc='glReplacementCodeuiVertex3fvSUN(GLuintArray(rc), GLfloatArray(v)) -> None',
argNames=('rc','v',),
deprecated=_DEPRECATED,
)

glReplacementCodeuiColor4ubVertex3fSUN = platform.createExtensionFunction( 
'glReplacementCodeuiColor4ubVertex3fSUN',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLubyte,constants.GLubyte,constants.GLubyte,constants.GLubyte,constants.GLfloat,constants.GLfloat,constants.GLfloat,),
doc='glReplacementCodeuiColor4ubVertex3fSUN(GLuint(rc), GLubyte(r), GLubyte(g), GLubyte(b), GLubyte(a), GLfloat(x), GLfloat(y), GLfloat(z)) -> None',
argNames=('rc','r','g','b','a','x','y','z',),
deprecated=_DEPRECATED,
)

glReplacementCodeuiColor4ubVertex3fvSUN = platform.createExtensionFunction( 
'glReplacementCodeuiColor4ubVertex3fvSUN',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(arrays.GLuintArray,arrays.GLubyteArray,arrays.GLfloatArray,),
doc='glReplacementCodeuiColor4ubVertex3fvSUN(GLuintArray(rc), GLubyteArray(c), GLfloatArray(v)) -> None',
argNames=('rc','c','v',),
deprecated=_DEPRECATED,
)

glReplacementCodeuiColor3fVertex3fSUN = platform.createExtensionFunction( 
'glReplacementCodeuiColor3fVertex3fSUN',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLfloat,constants.GLfloat,constants.GLfloat,constants.GLfloat,constants.GLfloat,constants.GLfloat,),
doc='glReplacementCodeuiColor3fVertex3fSUN(GLuint(rc), GLfloat(r), GLfloat(g), GLfloat(b), GLfloat(x), GLfloat(y), GLfloat(z)) -> None',
argNames=('rc','r','g','b','x','y','z',),
deprecated=_DEPRECATED,
)

glReplacementCodeuiColor3fVertex3fvSUN = platform.createExtensionFunction( 
'glReplacementCodeuiColor3fVertex3fvSUN',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(arrays.GLuintArray,arrays.GLfloatArray,arrays.GLfloatArray,),
doc='glReplacementCodeuiColor3fVertex3fvSUN(GLuintArray(rc), GLfloatArray(c), GLfloatArray(v)) -> None',
argNames=('rc','c','v',),
deprecated=_DEPRECATED,
)

glReplacementCodeuiNormal3fVertex3fSUN = platform.createExtensionFunction( 
'glReplacementCodeuiNormal3fVertex3fSUN',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLfloat,constants.GLfloat,constants.GLfloat,constants.GLfloat,constants.GLfloat,constants.GLfloat,),
doc='glReplacementCodeuiNormal3fVertex3fSUN(GLuint(rc), GLfloat(nx), GLfloat(ny), GLfloat(nz), GLfloat(x), GLfloat(y), GLfloat(z)) -> None',
argNames=('rc','nx','ny','nz','x','y','z',),
deprecated=_DEPRECATED,
)

glReplacementCodeuiNormal3fVertex3fvSUN = platform.createExtensionFunction( 
'glReplacementCodeuiNormal3fVertex3fvSUN',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(arrays.GLuintArray,arrays.GLfloatArray,arrays.GLfloatArray,),
doc='glReplacementCodeuiNormal3fVertex3fvSUN(GLuintArray(rc), GLfloatArray(n), GLfloatArray(v)) -> None',
argNames=('rc','n','v',),
deprecated=_DEPRECATED,
)

glReplacementCodeuiColor4fNormal3fVertex3fSUN = platform.createExtensionFunction( 
'glReplacementCodeuiColor4fNormal3fVertex3fSUN',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLfloat,constants.GLfloat,constants.GLfloat,constants.GLfloat,constants.GLfloat,constants.GLfloat,constants.GLfloat,constants.GLfloat,constants.GLfloat,constants.GLfloat,),
doc='glReplacementCodeuiColor4fNormal3fVertex3fSUN(GLuint(rc), GLfloat(r), GLfloat(g), GLfloat(b), GLfloat(a), GLfloat(nx), GLfloat(ny), GLfloat(nz), GLfloat(x), GLfloat(y), GLfloat(z)) -> None',
argNames=('rc','r','g','b','a','nx','ny','nz','x','y','z',),
deprecated=_DEPRECATED,
)

glReplacementCodeuiColor4fNormal3fVertex3fvSUN = platform.createExtensionFunction( 
'glReplacementCodeuiColor4fNormal3fVertex3fvSUN',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(arrays.GLuintArray,arrays.GLfloatArray,arrays.GLfloatArray,arrays.GLfloatArray,),
doc='glReplacementCodeuiColor4fNormal3fVertex3fvSUN(GLuintArray(rc), GLfloatArray(c), GLfloatArray(n), GLfloatArray(v)) -> None',
argNames=('rc','c','n','v',),
deprecated=_DEPRECATED,
)

glReplacementCodeuiTexCoord2fVertex3fSUN = platform.createExtensionFunction( 
'glReplacementCodeuiTexCoord2fVertex3fSUN',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLfloat,constants.GLfloat,constants.GLfloat,constants.GLfloat,constants.GLfloat,),
doc='glReplacementCodeuiTexCoord2fVertex3fSUN(GLuint(rc), GLfloat(s), GLfloat(t), GLfloat(x), GLfloat(y), GLfloat(z)) -> None',
argNames=('rc','s','t','x','y','z',),
deprecated=_DEPRECATED,
)

glReplacementCodeuiTexCoord2fVertex3fvSUN = platform.createExtensionFunction( 
'glReplacementCodeuiTexCoord2fVertex3fvSUN',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(arrays.GLuintArray,arrays.GLfloatArray,arrays.GLfloatArray,),
doc='glReplacementCodeuiTexCoord2fVertex3fvSUN(GLuintArray(rc), GLfloatArray(tc), GLfloatArray(v)) -> None',
argNames=('rc','tc','v',),
deprecated=_DEPRECATED,
)

glReplacementCodeuiTexCoord2fNormal3fVertex3fSUN = platform.createExtensionFunction( 
'glReplacementCodeuiTexCoord2fNormal3fVertex3fSUN',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLfloat,constants.GLfloat,constants.GLfloat,constants.GLfloat,constants.GLfloat,constants.GLfloat,constants.GLfloat,constants.GLfloat,),
doc='glReplacementCodeuiTexCoord2fNormal3fVertex3fSUN(GLuint(rc), GLfloat(s), GLfloat(t), GLfloat(nx), GLfloat(ny), GLfloat(nz), GLfloat(x), GLfloat(y), GLfloat(z)) -> None',
argNames=('rc','s','t','nx','ny','nz','x','y','z',),
deprecated=_DEPRECATED,
)

glReplacementCodeuiTexCoord2fNormal3fVertex3fvSUN = platform.createExtensionFunction( 
'glReplacementCodeuiTexCoord2fNormal3fVertex3fvSUN',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(arrays.GLuintArray,arrays.GLfloatArray,arrays.GLfloatArray,arrays.GLfloatArray,),
doc='glReplacementCodeuiTexCoord2fNormal3fVertex3fvSUN(GLuintArray(rc), GLfloatArray(tc), GLfloatArray(n), GLfloatArray(v)) -> None',
argNames=('rc','tc','n','v',),
deprecated=_DEPRECATED,
)

glReplacementCodeuiTexCoord2fColor4fNormal3fVertex3fSUN = platform.createExtensionFunction( 
'glReplacementCodeuiTexCoord2fColor4fNormal3fVertex3fSUN',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLfloat,constants.GLfloat,constants.GLfloat,constants.GLfloat,constants.GLfloat,constants.GLfloat,constants.GLfloat,constants.GLfloat,constants.GLfloat,constants.GLfloat,constants.GLfloat,constants.GLfloat,),
doc='glReplacementCodeuiTexCoord2fColor4fNormal3fVertex3fSUN(GLuint(rc), GLfloat(s), GLfloat(t), GLfloat(r), GLfloat(g), GLfloat(b), GLfloat(a), GLfloat(nx), GLfloat(ny), GLfloat(nz), GLfloat(x), GLfloat(y), GLfloat(z)) -> None',
argNames=('rc','s','t','r','g','b','a','nx','ny','nz','x','y','z',),
deprecated=_DEPRECATED,
)

glReplacementCodeuiTexCoord2fColor4fNormal3fVertex3fvSUN = platform.createExtensionFunction( 
'glReplacementCodeuiTexCoord2fColor4fNormal3fVertex3fvSUN',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(arrays.GLuintArray,arrays.GLfloatArray,arrays.GLfloatArray,arrays.GLfloatArray,arrays.GLfloatArray,),
doc='glReplacementCodeuiTexCoord2fColor4fNormal3fVertex3fvSUN(GLuintArray(rc), GLfloatArray(tc), GLfloatArray(c), GLfloatArray(n), GLfloatArray(v)) -> None',
argNames=('rc','tc','c','n','v',),
deprecated=_DEPRECATED,
)


def glInitVertexSUN():
    '''Return boolean indicating whether this extension is available'''
    return extensions.hasGLExtension( EXTENSION_NAME )



'''OpenGL extension EXT.index_material

Automatically generated by the get_gl_extensions script, do not edit!
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions
from OpenGL.GL import glget
import ctypes
EXTENSION_NAME = 'GL_EXT_index_material'
_DEPRECATED = False
GL_INDEX_MATERIAL_EXT = constant.Constant( 'GL_INDEX_MATERIAL_EXT', 0x81B8 )
GL_INDEX_MATERIAL_PARAMETER_EXT = constant.Constant( 'GL_INDEX_MATERIAL_PARAMETER_EXT', 0x81B9 )
GL_INDEX_MATERIAL_FACE_EXT = constant.Constant( 'GL_INDEX_MATERIAL_FACE_EXT', 0x81BA )
glIndexMaterialEXT = platform.createExtensionFunction( 
'glIndexMaterialEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLenum,),
doc='glIndexMaterialEXT(GLenum(face), GLenum(mode)) -> None',
argNames=('face','mode',),
deprecated=_DEPRECATED,
)


def glInitIndexMaterialEXT():
    '''Return boolean indicating whether this extension is available'''
    return extensions.hasGLExtension( EXTENSION_NAME )



'''OpenGL extension ARB.texture_gather

Automatically generated by the get_gl_extensions script, do not edit!
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions
from OpenGL.GL import glget
import ctypes
EXTENSION_NAME = 'GL_ARB_texture_gather'
_DEPRECATED = False
GL_MIN_PROGRAM_TEXTURE_GATHER_OFFSET = constant.Constant( 'GL_MIN_PROGRAM_TEXTURE_GATHER_OFFSET', 0x8E5E )
GL_MAX_PROGRAM_TEXTURE_GATHER_OFFSET = constant.Constant( 'GL_MAX_PROGRAM_TEXTURE_GATHER_OFFSET', 0x8E5F )
GL_MAX_PROGRAM_TEXTURE_GATHER_COMPONENTS = constant.Constant( 'GL_MAX_PROGRAM_TEXTURE_GATHER_COMPONENTS', 0x8F9F )


def glInitTextureGatherARB():
    '''Return boolean indicating whether this extension is available'''
    return extensions.hasGLExtension( EXTENSION_NAME )



'''OpenGL extension SGI.color_matrix

Automatically generated by the get_gl_extensions script, do not edit!
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions
from OpenGL.GL import glget
import ctypes
EXTENSION_NAME = 'GL_SGI_color_matrix'
_DEPRECATED = False
GL_COLOR_MATRIX_SGI = constant.Constant( 'GL_COLOR_MATRIX_SGI', 0x80B1 )
glget.addGLGetConstant( GL_COLOR_MATRIX_SGI, (4,4) )
GL_COLOR_MATRIX_STACK_DEPTH_SGI = constant.Constant( 'GL_COLOR_MATRIX_STACK_DEPTH_SGI', 0x80B2 )
glget.addGLGetConstant( GL_COLOR_MATRIX_STACK_DEPTH_SGI, (1,) )
GL_MAX_COLOR_MATRIX_STACK_DEPTH_SGI = constant.Constant( 'GL_MAX_COLOR_MATRIX_STACK_DEPTH_SGI', 0x80B3 )
glget.addGLGetConstant( GL_MAX_COLOR_MATRIX_STACK_DEPTH_SGI, (1,) )
GL_POST_COLOR_MATRIX_RED_SCALE_SGI = constant.Constant( 'GL_POST_COLOR_MATRIX_RED_SCALE_SGI', 0x80B4 )
glget.addGLGetConstant( GL_POST_COLOR_MATRIX_RED_SCALE_SGI, (1,) )
GL_POST_COLOR_MATRIX_GREEN_SCALE_SGI = constant.Constant( 'GL_POST_COLOR_MATRIX_GREEN_SCALE_SGI', 0x80B5 )
glget.addGLGetConstant( GL_POST_COLOR_MATRIX_GREEN_SCALE_SGI, (1,) )
GL_POST_COLOR_MATRIX_BLUE_SCALE_SGI = constant.Constant( 'GL_POST_COLOR_MATRIX_BLUE_SCALE_SGI', 0x80B6 )
glget.addGLGetConstant( GL_POST_COLOR_MATRIX_BLUE_SCALE_SGI, (1,) )
GL_POST_COLOR_MATRIX_ALPHA_SCALE_SGI = constant.Constant( 'GL_POST_COLOR_MATRIX_ALPHA_SCALE_SGI', 0x80B7 )
glget.addGLGetConstant( GL_POST_COLOR_MATRIX_ALPHA_SCALE_SGI, (1,) )
GL_POST_COLOR_MATRIX_RED_BIAS_SGI = constant.Constant( 'GL_POST_COLOR_MATRIX_RED_BIAS_SGI', 0x80B8 )
glget.addGLGetConstant( GL_POST_COLOR_MATRIX_RED_BIAS_SGI, (1,) )
GL_POST_COLOR_MATRIX_GREEN_BIAS_SGI = constant.Constant( 'GL_POST_COLOR_MATRIX_GREEN_BIAS_SGI', 0x80B9 )
glget.addGLGetConstant( GL_POST_COLOR_MATRIX_GREEN_BIAS_SGI, (1,) )
GL_POST_COLOR_MATRIX_BLUE_BIAS_SGI = constant.Constant( 'GL_POST_COLOR_MATRIX_BLUE_BIAS_SGI', 0x80BA )
glget.addGLGetConstant( GL_POST_COLOR_MATRIX_BLUE_BIAS_SGI, (1,) )
GL_POST_COLOR_MATRIX_ALPHA_BIAS_SGI = constant.Constant( 'GL_POST_COLOR_MATRIX_ALPHA_BIAS_SGI', 0x80BB )
glget.addGLGetConstant( GL_POST_COLOR_MATRIX_ALPHA_BIAS_SGI, (1,) )


def glInitColorMatrixSGI():
    '''Return boolean indicating whether this extension is available'''
    return extensions.hasGLExtension( EXTENSION_NAME )



'''OpenGL extension ARB.texture_mirrored_repeat

This module customises the behaviour of the 
OpenGL.raw.GL.ARB.texture_mirrored_repeat to provide a more 
Python-friendly API

Overview (from the spec)
	
	ARB_texture_mirrored_repeat extends the set of texture wrap modes to
	include a mode (GL_MIRRORED_REPEAT_ARB) that effectively uses a texture
	map twice as large at the original image in which the additional half,
	for each coordinate, of the new image is a mirror image of the original
	image.
	
	This new mode relaxes the need to generate images whose opposite edges
	match by using the original image to generate a matching "mirror image".

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/ARB/texture_mirrored_repeat.txt
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions, wrapper
from OpenGL.GL import glget
import ctypes
from OpenGL.raw.GL.ARB.texture_mirrored_repeat import *
### END AUTOGENERATED SECTION


'''OpenGL extension ATI.pn_triangles

Automatically generated by the get_gl_extensions script, do not edit!
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions
from OpenGL.GL import glget
import ctypes
EXTENSION_NAME = 'GL_ATI_pn_triangles'
_DEPRECATED = False
GL_PN_TRIANGLES_ATI = constant.Constant( 'GL_PN_TRIANGLES_ATI', 0x87F0 )
GL_MAX_PN_TRIANGLES_TESSELATION_LEVEL_ATI = constant.Constant( 'GL_MAX_PN_TRIANGLES_TESSELATION_LEVEL_ATI', 0x87F1 )
glget.addGLGetConstant( GL_MAX_PN_TRIANGLES_TESSELATION_LEVEL_ATI, (1,) )
GL_PN_TRIANGLES_POINT_MODE_ATI = constant.Constant( 'GL_PN_TRIANGLES_POINT_MODE_ATI', 0x87F2 )
glget.addGLGetConstant( GL_PN_TRIANGLES_POINT_MODE_ATI, (1,) )
GL_PN_TRIANGLES_NORMAL_MODE_ATI = constant.Constant( 'GL_PN_TRIANGLES_NORMAL_MODE_ATI', 0x87F3 )
glget.addGLGetConstant( GL_PN_TRIANGLES_NORMAL_MODE_ATI, (1,) )
GL_PN_TRIANGLES_TESSELATION_LEVEL_ATI = constant.Constant( 'GL_PN_TRIANGLES_TESSELATION_LEVEL_ATI', 0x87F4 )
glget.addGLGetConstant( GL_PN_TRIANGLES_TESSELATION_LEVEL_ATI, (1,) )
GL_PN_TRIANGLES_POINT_MODE_LINEAR_ATI = constant.Constant( 'GL_PN_TRIANGLES_POINT_MODE_LINEAR_ATI', 0x87F5 )
GL_PN_TRIANGLES_POINT_MODE_CUBIC_ATI = constant.Constant( 'GL_PN_TRIANGLES_POINT_MODE_CUBIC_ATI', 0x87F6 )
GL_PN_TRIANGLES_NORMAL_MODE_LINEAR_ATI = constant.Constant( 'GL_PN_TRIANGLES_NORMAL_MODE_LINEAR_ATI', 0x87F7 )
GL_PN_TRIANGLES_NORMAL_MODE_QUADRATIC_ATI = constant.Constant( 'GL_PN_TRIANGLES_NORMAL_MODE_QUADRATIC_ATI', 0x87F8 )
glPNTrianglesiATI = platform.createExtensionFunction( 
'glPNTrianglesiATI',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLint,),
doc='glPNTrianglesiATI(GLenum(pname), GLint(param)) -> None',
argNames=('pname','param',),
deprecated=_DEPRECATED,
)

glPNTrianglesfATI = platform.createExtensionFunction( 
'glPNTrianglesfATI',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLfloat,),
doc='glPNTrianglesfATI(GLenum(pname), GLfloat(param)) -> None',
argNames=('pname','param',),
deprecated=_DEPRECATED,
)


def glInitPnTrianglesATI():
    '''Return boolean indicating whether this extension is available'''
    return extensions.hasGLExtension( EXTENSION_NAME )



import sys, pygame
from math import sin
from pygame.locals import *
from OpenGL.GL import *
from OpenGL.GL.shaders import *
from OpenGL.GL.ARB.shader_objects import glGetActiveUniformARB

vertex_shader = """
uniform float scale;
void main(void)
{
    gl_Position = gl_ModelViewProjectionMatrix * gl_Vertex * scale;
}
"""

pygame.init()
disp = pygame.display.set_mode((1024, 768), OPENGL | DOUBLEBUF)

program = compileProgram(
    compileShader( vertex_shader, GL_VERTEX_SHADER )
)

nu = glGetProgramiv(program, GL_ACTIVE_UNIFORMS)
for i in range(nu):
    name, size, type = glGetActiveUniform(program, i)
    print 'CORE - ', name, size, type
    glGetActiveUniformARB( program, i )
    print 'ARB  - ', name, size, type
